__copyright__ = "Copyright (c) 2017 CollabNet, Inc. All rights reserved."

from app.scripts import BaseCreateRuntimeScript
import app.certstore
import app.defaults
import shutil
import os

class CreateRuntimeScript(BaseCreateRuntimeScript):

    scriptDescription = "Autogenerate/copy SSL certificates"

    def __isSSLEnabled(self):
        return self.cfg.get("SSL", "off").lower() == "on"

    def createRuntime(self):
        if not self.__isSSLEnabled():
            return
        
        if not os.path.isdir(app.defaults.DEFAULT_SSLCERTS_PATH):
            os.makedirs(app.defaults.DEFAULT_SSLCERTS_PATH)

        domainName = app.landscape.Landscape.getSite().getLocalMachine().getPublicAddress().getName()

        targetCertPath = os.path.join(app.defaults.DEFAULT_SSLCERTS_PATH, domainName + ".crt")
        targetKeyPath  = os.path.join(app.defaults.DEFAULT_SSLCERTS_PATH, domainName + ".key")

        userCertPath = self.cfg["SSL_CERT_FILE"]
        userKeyPath  = self.cfg["SSL_KEY_FILE"]

        if not (os.path.isfile(userCertPath) and os.path.isfile(userKeyPath)):
            self.log.info("Generating self-signed SSL certiticates for '%s'" % domainName)
            app.certstore.CertificateGenerator.createSelfSignedCertificate(
                domainName,
                app.defaults.DEFAULT_CERTIFICATE_VALIDITY_PERIOD,
                targetCertPath,
                targetKeyPath)

        elif userCertPath == targetCertPath and userKeyPath == targetKeyPath:
            self.log.info("Keeping existing SSL certiticates for '%s'" % domainName)

        else:
            self.log.info("Using user-provided SSL certiticates for '%s'" % domainName)
            shutil.copy(userCertPath, targetCertPath)
            shutil.copy(userKeyPath, targetKeyPath)

            targetChainFile = os.path.join(app.defaults.DEFAULT_SSLCERTS_PATH, "intermediate.crt")
            userChainFile = self.cfg.get("SSL_CHAIN_FILE")

            if userChainFile and os.path.isfile(userChainFile):
                shutil.copy(userChainFile, targetChainFile)
                self.__setFilePermission(targetChainFile)

        self.__setFilePermission(targetCertPath)
        self.__setFilePermission(targetKeyPath)

    def __setFilePermission(self, certFile):
        os.system("chown root:root %s" % certFile)
        os.chmod(certFile, 0600)
