import os
import app.servicecontrol

class ServiceController(app.servicecontrol.ServiceController):
    def getPidFile(self):
        return os.path.join("/var/run/collabnet-nginx/run/nginx.pid")

    def __runInit(self, verb):
        config = app.util.getRuntimeConfiguration()

        logFile = os.path.join(config['EVENTQ_LOG_DIR'], 'service.log') 
        # TODO: for us, should this be the nginx init.d scripts?
        initScript = '/etc/init.d/collabnet-nginx'

        return os.system("%s %s < /dev/null >> %s 2>&1 &" % (initScript, verb, logFile)) == 0

    def startDaemonAsync(self):
        self.queuerunnerStartDaemonAsync()
        return self.__runInit("start")

    def stopDaemonAsync(self):
        self.queuerunnerStopDaemonAsync()
        return self.__runInit("stop")

    def __queuerunnerInit(self, service, verb):
        initScript = "/etc/init.d/" + service
        return os.system("%s %s > /dev/null" % (initScript, verb))

    def queuerunnerStartDaemonAsync(self):
        # NOTE: This class does not handle the startup of queuerunners, just
        # their shutdown.  Startup of the queuerunners is handled by the
        # initialization phase.  The reason for this is that the runners should
        # not be started until other services (i.e., MongoDB and RabbitMQ) have
        # had their users and passwords finalized, which doesn't happen until
        # their initialization is complete.
        pass

    def queuerunnerStopDaemonAsync(self):
        # NOTE: The startup of queuerunners bypasses systemctl on startup, so
        # we have to skip it on shutdown as well:
        os.environ["SYSTEMCTL_SKIP_REDIRECT"] = "1"

        services = ['eventq-queue-build', 'eventq-queue-commit',
                    'eventq-queue-review', 'eventq-ctf-jobs',
                    'eventq-queue-work-item', 'eventq-queue-custom',
                    'eventq-queue-ctf-user-permission']
        for service in services:
            self.__queuerunnerInit(service, 'stop')
